export type NvimVersion = {
    /** Path to `nvim` executable. */
    readonly path: string;
    /** Nvim version, or undefined if there was an error. */
    readonly nvimVersion?: string;
    /** Nvim build type, or undefined if there was an error. */
    readonly buildType?: string;
    /** Nvim LuaJIT version, or undefined if there was an error. */
    readonly luaJitVersion?: string;
    /** Error caught while attempting to access or run Nvim at the given path. */
    readonly error?: Readonly<Error>;
};
export type GetNvimFromEnvOptions = {
    /**
     * (Optional) Minimum `nvim` version (inclusive) to search for.
     *
     * - Example: `'0.5.0'`
     */
    readonly minVersion?: string;
    /**
     * (Optional) Sort order of list of `nvim` versions.
     *
     * - "desc" - Sort by version in descending order (highest to lowest).
     *   - Example: `['0.5.0', '0.4.4', '0.4.3']`
     * - "none" - (Default) Order is that of the searched `$PATH` components.
     *   - Example: `['0.4.4', '0.5.0', '0.4.3']`
     */
    readonly orderBy?: 'desc' | 'none';
};
export type GetNvimFromEnvResult = {
    /**
     * List of satisfying `nvim` versions found (if any) on the current system, sorted in the order
     * specified by `orderBy`.
     */
    readonly matches: ReadonlyArray<NvimVersion>;
    /**
     * List of invalid or failed `nvim` versions found (if any), in order of searched `$PATH` components.
     */
    readonly invalid: ReadonlyArray<NvimVersion>;
};
/**
 * Tries to find a usable `nvim` binary on the current system.
 */
export declare function getNvimFromEnv(opt?: GetNvimFromEnvOptions): Readonly<GetNvimFromEnvResult>;
export declare let exportsForTesting: any;
